@@ -43,11 +43,13 @@
 
 #include "codeeditor.h"
 #include "shx_helper.h"
-#include "chgl.h"
+//#include "chgl.h"
 
 CodeEditor::CodeEditor(QWidget *parent) : QPlainTextEdit(parent), c(0){
   lineNumberArea = new LineNumberArea(this);
+  lineNumberArea->setObjectName("lineNumberArea");
   afixHighlightArea = new AfixHighlightArea(this);
+  afixHighlightArea->setObjectName("afixHighlightArea");
   setMouseTracking(true);
   midCursorpos=0;
   //setTabChangesFocus(true);
@@ -125,7 +127,7 @@ void CodeEditor::lineNumberAreaPaintEvent(QPaintEvent *event){
   int current = textCursor().blockNumber();
   painter.fillRect(event->rect(), QColor("#eeeeee"));
   QTextBlock block = firstVisibleBlock();
-  //printf("edidor Font: %s\n",fontInfo().family().toStdString().c_str());
+ // printf("edidor Font: %s italic%d bold %d point %d pixel %d height %d\n",fontInfo().family().toStdString().c_str(),fontInfo().italic (),fontInfo().bold (),fontInfo().pointSize (),fontInfo().pixelSize (),fontMetrics().height());
 //   printf("lineNumberAreaPaintEvent\n");
   int blockNumber = block.blockNumber();
   int top = (int) blockBoundingGeometry(block).translated(contentOffset()).top();
@@ -188,6 +190,7 @@ void CodeEditor::lineNumberToggled(QMouseEvent *event){
     int top = (int) blockBoundingGeometry(block).translated(contentOffset()).top();
     int bn=firstVisibleBlock().blockNumber();
     int idx=(int)  (event->y()-top)/ ((int) blockBoundingRect(block).height()) + bn + 1;
+//    printf("remark->  idx-1 %d  event.y %d top %d first %d height %g\n",idx-1,event->y(),top,bn,blockBoundingRect(block).height());
 remark(idx-1);
 }
 
@@ -543,8 +546,8 @@ QString CodeEditor::textUnderCursor() const{
     tc.select(QTextCursor::WordUnderCursor);
     if (tc.selectedText().contains("_")) return "";
     int si=tc.selectedText().size();
-    if (tc.selectedText().startsWith('r',Qt::CaseSensitive))
-        return tc.selectedText().section(QRegExp("[A-Z]+",Qt::CaseSensitive),0,0).toUpper();
+    //if (tc.selectedText().startsWith('r',Qt::CaseSensitive))
+    //    return tc.selectedText().section(QRegExp("[A-Z]+",Qt::CaseSensitive),0,0).toUpper();
     //    printf("%d %d\n", (tc.selectionStart ()  - tc.block().position()) ,si);
     if (((tc.selectionStart () - tc.block().position())<4)&&(si>4)) return tc.selectedText().left(si-4);
     if ((tc.position() - tc.block().position())>2) return "";
@@ -564,13 +567,13 @@ void CodeEditor::focusInEvent(QFocusEvent *e){
 
 void CodeEditor::keyPressEvent(QKeyEvent *e){
 //    printf("kp\n");
-    if (!chgl->mol->selectedatoms.isEmpty()){
+//    if (!chgl->mol->selectedatoms.isEmpty()){
     if ((e->modifiers() & Qt::ControlModifier)&&(e->key()==Qt::Key_Delete)) {
       	e->ignore();
         emit deleteSelected();
 	return;
     }
-    }
+    //}
     if (c && c->popup()->isVisible()) {
         // The following keys are forwarded by the completer to the widget
        switch (e->key()) {
@@ -599,7 +602,6 @@ void CodeEditor::keyPressEvent(QKeyEvent *e){
     static QString eow("!"); // end of word
     bool hasModifier = (e->modifiers() != Qt::NoModifier) && !ctrlOrShift;
     QString completionPrefix = textUnderCursor();
-
     if ((hasModifier || e->text().isEmpty()|| completionPrefix.length() < 1
                       || eow.contains(e->text().right(1)))) {
         c->popup()->hide();
