@@ -400,6 +400,120 @@ void EacDlg::colorDLG2(){
   mol->einstellung->setValue("BondColor",mol->bondColor);
   mol->einstellung->setValue("BondStyle",mol->bondColorStyle);
   mol->einstellung->setValue("BondStrength",mol->bondStrength);
+
+  mol->einstellung->setValue("enviBondColor",mol->enviBondColor);
+  mol->einstellung->setValue("enviHBColor",mol->enviHBColor);
+  mol->einstellung->setValue("enviDefaultColor",mol->enviDefaultColor);
+  mol->einstellung->endGroup();
+  }
+  update();
+}
+
+void EacDlg::colorDLGenvidef(){
+  QColor bgcolor;
+  bgcolor=QColorDialog::getColor(mol->enviDefaultColor, this);
+  if (bgcolor.isValid()) {
+    mol->enviDefaultColor=eacGLW->mol->enviDefaultColor=bgcolor;
+
+    colorbutEdf->setStyleSheet(QString(
+                "QPushButton {"
+                "border: 1px solid #000000;"
+                "border-radius: 9px;"
+                "color: %4;"
+                "background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 %1, stop: 0.5 %3, stop: 1 %2);"
+                "}"
+                "QPushButton:hover {"
+                "background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 %2, stop: 0.5 %1, stop: 1 %2);"
+                "}"
+                "QPushButton:flat {"
+                "    border: none; /* no border for a flat push button */"
+                "}"
+                )
+            .arg(bgcolor.name())
+            .arg(bgcolor.darker(200).name())
+            .arg(bgcolor.lighter(200).name())
+            .arg((bgcolor.value()<90)?"#ffffff":"#000000"));
+  mol->einstellung->beginGroup("Bonds");
+  mol->einstellung->setValue("BondColor",mol->bondColor);
+  mol->einstellung->setValue("BondStyle",mol->bondColorStyle);
+  mol->einstellung->setValue("BondStrength",mol->bondStrength);
+
+  mol->einstellung->setValue("enviBondColor",mol->enviBondColor);
+  mol->einstellung->setValue("enviHBColor",mol->enviHBColor);
+  mol->einstellung->setValue("enviDefaultColor",mol->enviDefaultColor);
+  mol->einstellung->endGroup();
+  }
+  update();
+}
+void EacDlg::colorDLGenvibon(){
+  QColor bgcolor;
+  bgcolor=QColorDialog::getColor(mol->enviBondColor, this);
+  if (bgcolor.isValid()) {
+    mol->enviBondColor=eacGLW->mol->enviBondColor=bgcolor;
+
+    colorbutEbo->setStyleSheet(QString(
+                "QPushButton {"
+                "border: 1px solid #000000;"
+                "border-radius: 9px;"
+                "color: %4;"
+                "background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 %1, stop: 0.5 %3, stop: 1 %2);"
+                "}"
+                "QPushButton:hover {"
+                "background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 %2, stop: 0.5 %1, stop: 1 %2);"
+                "}"
+                "QPushButton:flat {"
+                "    border: none; /* no border for a flat push button */"
+                "}"
+                )
+            .arg(bgcolor.name())
+            .arg(bgcolor.darker(200).name())
+            .arg(bgcolor.lighter(200).name())
+            .arg((bgcolor.value()<90)?"#ffffff":"#000000"));
+  mol->einstellung->beginGroup("Bonds");
+  mol->einstellung->setValue("BondColor",mol->bondColor);
+  mol->einstellung->setValue("BondStyle",mol->bondColorStyle);
+  mol->einstellung->setValue("BondStrength",mol->bondStrength);
+
+  mol->einstellung->setValue("enviBondColor",mol->enviBondColor);
+  mol->einstellung->setValue("enviHBColor",mol->enviHBColor);
+  mol->einstellung->setValue("enviDefaultColor",mol->enviDefaultColor);
+  mol->einstellung->endGroup();
+  }
+  update();
+}
+
+void EacDlg::colorDLGenvihbo(){
+  QColor bgcolor;
+  bgcolor=QColorDialog::getColor(mol->enviHBColor, this);
+  if (bgcolor.isValid()) {
+    mol->enviHBColor=eacGLW->mol->enviHBColor=bgcolor;
+
+    colorbutEhb->setStyleSheet(QString(
+                "QPushButton {"
+                "border: 1px solid #000000;"
+                "border-radius: 9px;"
+                "color: %4;"
+                "background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 %1, stop: 0.5 %3, stop: 1 %2);"
+                "}"
+                "QPushButton:hover {"
+                "background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 %2, stop: 0.5 %1, stop: 1 %2);"
+                "}"
+                "QPushButton:flat {"
+                "    border: none; /* no border for a flat push button */"
+                "}"
+                )
+            .arg(bgcolor.name())
+            .arg(bgcolor.darker(200).name())
+            .arg(bgcolor.lighter(200).name())
+            .arg((bgcolor.value()<90)?"#ffffff":"#000000"));
+  mol->einstellung->beginGroup("Bonds");
+  mol->einstellung->setValue("BondColor",mol->bondColor);
+  mol->einstellung->setValue("BondStyle",mol->bondColorStyle);
+  mol->einstellung->setValue("BondStrength",mol->bondStrength);
+
+  mol->einstellung->setValue("enviBondColor",mol->enviBondColor);
+  mol->einstellung->setValue("enviHBColor",mol->enviHBColor);
+  mol->einstellung->setValue("enviDefaultColor",mol->enviDefaultColor);
   mol->einstellung->endGroup();
   }
   update();
@@ -520,6 +634,10 @@ void EacDlg::unicolor(bool b){
   mol->einstellung->setValue("BondColor",mol->bondColor);
   mol->einstellung->setValue("BondStyle",mol->bondColorStyle);
   mol->einstellung->setValue("BondStrength",mol->bondStrength);
+  mol->einstellung->setValue("enviBondColor",mol->enviBondColor);
+  mol->einstellung->setValue("enviHBColor",mol->enviHBColor);
+  mol->einstellung->setValue("enviDefaultColor",mol->enviDefaultColor);
+
   mol->einstellung->endGroup();
   update();
 }
@@ -530,6 +648,9 @@ void EacDlg::strengthChanged(double d){
   mol->einstellung->setValue("BondColor",mol->bondColor);
   mol->einstellung->setValue("BondStyle",mol->bondColorStyle);
   mol->einstellung->setValue("BondStrength",mol->bondStrength);
+  mol->einstellung->setValue("enviBondColor",mol->enviBondColor);
+  mol->einstellung->setValue("enviHBColor",mol->enviHBColor);
+  mol->einstellung->setValue("enviDefaultColor",mol->enviDefaultColor);
   mol->einstellung->endGroup();
   update();
 }
@@ -599,6 +720,10 @@ void EacDlg::importSettings(){
   mol->bondColor = eaSettings->value("BondColor").value<QColor>();
   mol->bondColorStyle = eaSettings->value("BondStyle").toInt();;
   mol->bondStrength = eaSettings->value("BondStrength").toDouble();
+
+  mol->enviBondColor=eaSettings->value("enviBondColor",Qt::darkGreen).value<QColor>();
+  mol->enviHBColor=eaSettings->value("enviHBColor",Qt::darkYellow).value<QColor>();
+  mol->enviDefaultColor=eaSettings->value("enviDefaultColor",Qt::black).value<QColor>();
   
   eaSettings->endGroup();
   delete eaSettings;
@@ -640,6 +765,9 @@ void EacDlg::importSettings(){
   mol->einstellung->setValue("BondColor",mol->bondColor);
   mol->einstellung->setValue("BondStyle",mol->bondColorStyle);
   mol->einstellung->setValue("BondStrength",mol->bondStrength);
+  mol->einstellung->setValue("enviBondColor",mol->enviBondColor);
+  mol->einstellung->setValue("enviHBColor",mol->enviHBColor);
+  mol->einstellung->setValue("enviDefaultColor",mol->enviDefaultColor);
   mol->einstellung->endGroup();
   //--------------------------------------
 }
@@ -688,6 +816,9 @@ void EacDlg::exportSettings(){
   eaSettings->setValue("BondColor",mol->bondColor);
   eaSettings->setValue("BondStyle",mol->bondColorStyle);
   eaSettings->setValue("BondStrength",mol->bondStrength);
+  eaSettings->setValue("enviBondColor",mol->enviBondColor);
+  eaSettings->setValue("enviHBColor",mol->enviHBColor);
+  eaSettings->setValue("enviDefaultColor",mol->enviDefaultColor);
 
   eaSettings->setValue("HBondMaxDist",mol->hbdist());
   eaSettings->value("HBondMaxAng",mol->hbangl());
@@ -818,6 +949,73 @@ EacDlg::EacDlg(Molecule *externMole){
 		  .arg(mol->bondColor.lighter(200).name())
 		  .arg((mol->bondColor.value()<90)?"#ffffff":"#000000"));
   connect(colorbut2,SIGNAL(pressed()),this,SLOT(colorDLG2()));
+
+
+  colorbutEdf =new QPushButton("ENVI default color");
+  colorbutEdf->setStyleSheet(QString(
+              "QPushButton {"
+              "border: 1px solid #000000;"
+              "border-radius: 9px;"
+              "color: %4;"
+              "background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 %1, stop: 0.5 %3, stop: 1 %2);"
+              "}"
+              "QPushButton:hover {"
+              "background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 %1, stop: 0.5 %2, stop: 1 %1);"
+              "border: 0px"
+              "}"
+              "QPushButton:flat {"
+              "    border: none; /* no border for a flat push button */"
+              "}"
+              )
+          .arg(mol->enviDefaultColor.name())
+          .arg(mol->enviDefaultColor.darker(200).name())
+          .arg(mol->enviDefaultColor.lighter(200).name())
+          .arg((mol->enviDefaultColor.value()<90)?"#ffffff":"#000000"));
+  connect(colorbutEdf,SIGNAL(pressed()),this,SLOT(colorDLGenvidef()));
+
+  colorbutEbo =new QPushButton("ENVI covalent color");
+  colorbutEbo->setStyleSheet(QString(
+              "QPushButton {"
+              "border: 1px solid #000000;"
+              "border-radius: 9px;"
+              "color: %4;"
+              "background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 %1, stop: 0.5 %3, stop: 1 %2);"
+              "}"
+              "QPushButton:hover {"
+              "background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 %1, stop: 0.5 %2, stop: 1 %1);"
+              "border: 0px"
+              "}"
+              "QPushButton:flat {"
+              "    border: none; /* no border for a flat push button */"
+              "}"
+              )
+          .arg(mol->enviBondColor.name())
+          .arg(mol->enviBondColor.darker(200).name())
+          .arg(mol->enviBondColor.lighter(200).name())
+          .arg((mol->enviBondColor.value()<90)?"#ffffff":"#000000"));
+  connect(colorbutEbo,SIGNAL(pressed()),this,SLOT(colorDLGenvibon()));
+
+  colorbutEhb =new QPushButton("ENVI H-Bond color");
+  colorbutEhb->setStyleSheet(QString(
+              "QPushButton {"
+              "border: 1px solid #000000;"
+              "border-radius: 9px;"
+              "color: %4;"
+              "background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 %1, stop: 0.5 %3, stop: 1 %2);"
+              "}"
+              "QPushButton:hover {"
+              "background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 %1, stop: 0.5 %2, stop: 1 %1);"
+              "border: 0px"
+              "}"
+              "QPushButton:flat {"
+              "    border: none; /* no border for a flat push button */"
+              "}"
+              )
+          .arg(mol->enviHBColor.name())
+          .arg(mol->enviHBColor.darker(200).name())
+          .arg(mol->enviHBColor.lighter(200).name())
+          .arg((mol->enviHBColor.value()<90)?"#ffffff":"#000000"));
+  connect(colorbutEhb,SIGNAL(pressed()),this,SLOT(colorDLGenvihbo()));
   bondStrength = new QDoubleSpinBox();
   bondStrength->setValue(mol->bondStrength);
   bondStrength->setDecimals(2);
@@ -827,6 +1025,9 @@ EacDlg::EacDlg(Molecule *externMole){
   glt->addWidget(eacProba);
   glt->addWidget(singleC);
   glt->addWidget(colorbut2);
+  glt->addWidget(colorbutEdf);
+  glt->addWidget(colorbutEbo);
+  glt->addWidget(colorbutEhb);
   QHBoxLayout *glt2= new QHBoxLayout();
   QHBoxLayout *glt5= new QHBoxLayout();
   QHBoxLayout *glt6= new QHBoxLayout();
