@@ -95,6 +95,9 @@ Q_OBJECT
   EacGLW *eacGLW;//!<The QGLWidget displaying an example molecule.
   public slots:
   void colorDLG2();//!< opens the bond color dialog.
+  void colorDLGenvibon();
+  void colorDLGenvidef();
+  void colorDLGenvihbo();
   void colorchange(QColor bgcolor);//!< changes the color of the current element to bgcolor. Changes the color of the corresponding button.
   void updateLEs(int OZ);//!< when the current element changes the settings of this element are loaded and applied to the EacGLW widget and the PSEWidget. @param OZ atomic number (staring from zero) of the new atom
   void checkWall();//!< when solid is checked then solid is unchecked.
@@ -123,7 +126,7 @@ Q_OBJECT
   QSpinBox *lodSpinBox;
   QComboBox *eacProba;
   PSEWidget *psew;
-  QPushButton *colorbut, *colorbut2,*impbut,*expbut;
+  QPushButton *colorbut, *colorbut2,*colorbutEhb,*colorbutEbo,*colorbutEdf,*impbut,*expbut;
   QGridLayout *eacGLO;
   //QComboBox *eacCB;
   QDoubleSpinBox *eacRAD;
