@@ -42,8 +42,10 @@ FourXle::FourXle(Molecule *mole_, ChGL *chgl_,QToolBar *toolView, double resol,
   rr=resol;
   rw=wght; 
   chgl->foact=toolView->addAction(QIcon(":/icons/fomap.png"),"toggle Fo map",chgl,SLOT(updateGL()));
+  connect(chgl->foact,SIGNAL(destroyed(QObject*)),this,SLOT(foactDestroyed()));
   chgl->foact->setCheckable(true);
   chgl->fofcact=toolView->addAction(QIcon(":/icons/diffmap.png"),"toggle Fo-Fc map",chgl,SLOT(updateGL()));
+  connect(chgl->fofcact,SIGNAL(destroyed(QObject*)),this,SLOT(fofcactDestroyed()));
   chgl->fofcact->setCheckable(true);
   chgl->fofcact->setVisible(false);
   chgl->foact->setVisible(false);
@@ -63,8 +65,8 @@ FourXle::~FourXle(){
 void FourXle::killmaps(){
   /*! deletes all fourier maps and frees the memory
    */
-  chgl->fofcact->setVisible(false);
-  chgl->foact->setVisible(false);
+  if (chgl->fofcact!=NULL) chgl->fofcact->setVisible(false);
+  if (chgl->foact!=NULL) chgl->foact->setVisible(false);
   if (datfo!=NULL) free(datfo);
   if (datfo_fc!=NULL) free(datfo_fc);
   datfo=datfo_fc=NULL;
@@ -959,6 +961,14 @@ void FourXle::change_iso(int numsteps,int diff){
   chgl->updateGL();
 }
 
+void FourXle::foactDestroyed() {
+  chgl->foact = NULL;
+}
+
+void FourXle::fofcactDestroyed() {
+  chgl->fofcact = NULL;
+}
+
 void FourXle::CalcVertex( int ix, int iy, int iz) {
   V3 mdz=(0.5*dx)+(0.5*dy)+(0.5*dz);
   V3 o,fl,m2u=V3(0.5,0.5,0.5);
