@@ -121,6 +121,8 @@ Q_OBJECT
           void bewegt(V3 v);
           void inimap();
           void change_iso(int numsteps,int diff);
+          void foactDestroyed();
+          void fofcactDestroyed();
   signals:
   void bigmessage(const QString &);//!< to comunicate with the informaton window
 
