@@ -1161,6 +1161,10 @@ public:
   double  pmin,//!< minimum peak height of the Q-Peaks.
 	  pmax;//!< maximum peak height of the Q-Peaks.
   QColor bondColor;//!< the color of the bonds in uni colored mode.
+
+  QColor enviBondColor,//!< covalent color in ENVI
+      enviHBColor,//!< hydrogen bond color in ENVI
+      enviDefaultColor;//!< default color in ENVI
   CEnvironment asymm,//!< atom list containing the asymertic unit 
 	       showatoms,//!< atom list containing all atoms to be drawn.
 	       selectedatoms,//!< atom list of selected atoms.
