@@ -24,7 +24,7 @@ PSEWidget::PSEWidget(QWidget *parent) :
     selection=0;
     static QStringList PSE;
     mole.loadSettings();
-#define PROGRAM_NAME "shelXle"
+//#define PROGRAM_NAME "shelXle"
     mole.einstellung = new QSettings( QSettings::IniFormat, QSettings::UserScope ,PROGRAM_NAME,PROGRAM_NAME ,this);
     sz=mole.pseSize;
     PSE.clear();
