@@ -3,10 +3,7 @@
 
 #include <QtGui>
 #include "molecule.h"
-#ifndef PROGRAM_NAME
-#define PROGRAM_NAME "shelXle"
-#endif
-
+#include "itsme.h"
 #include "codeeditor.h"
 
 //! DragVersion is a QLabel that represents an earlier version of a res file and shows the time elapsed since it was saved. Used in SaveHistoryWidget
