@@ -20,7 +20,7 @@
 #define WINDOW_H
 #include <QtGui>
 #include <QtNetwork>
-#include <QtWebKit>
+// #include <QtWebKit>
 #include "chgl.h"
 #include "highlighter.h"
 #include "codeeditor.h"
@@ -28,11 +28,11 @@
 #include "qpeakview.h"
 #include "psewidget.h"
 #include "dragdropatomsdlg.h"
-#define PROGRAM_NAME "shelXle"
 #include "historywidget.h"
 #include "savehistorywidget.h"
 #include "fourxle.h"
 #include "fcvsfo.h"
+#include "itsme.h"
 #ifndef fmin
 #define fmin(x, y) (((x) < (y)) ? (x) : (y))
 #endif
@@ -45,6 +45,7 @@
 int finite(double arg);
 #define vc7hack1 1
 #endif
+#include "calculator.h"
 
 /*! \brief Window is the main window class of ShelXle most of the magic happens here ;-)
 *
@@ -54,6 +55,7 @@ class Window : public QMainWindow {
 Q_OBJECT
 public:
   Window();
+  virtual ~Window();
   //bool scroller;
   ChGL *chgl;  
   QDockWidget *dock, *renamDock, *qPeakDock, *histDock;
@@ -165,10 +167,12 @@ public:
   void jnk();//!< Julian Henn and Kathrin Meindl frcatal dimension analisis
   void jumpToAtom(int index);//!< if rename mode is visible the atom at index gets renamed if not the cursor of the editor is pointed to the specified atom.
   void jumpToError();//!< the cursor points to the first syntax error in the file.
+  void linkHelp();//!< Show a Link to the online help. 
   void loadAFile();//!< (re)loads the file specified in dirName.
   void loadFile(QString fileName);//!< loads the file with the specified path the listfile is also loaded. @param fileName path to the res / ins file.
   void loadLst();//!< loads the .lst file if it exists.
   void loadrefres();//!< loads the refinement results from the res file.
+  void loadThisFile();//!< loads a file from an QAction with path as Action data. 
   void mapDefault();//!< restores the defaults of the Map Control dialog.
   void moveSymmMate();//!< Moves the specified symmetry generated atom to the asymmetric unit.
   void moveSymmMateSel();//!< Moves selected symmetry generated atoms to the asymmetric unit.
@@ -178,7 +182,17 @@ public:
   void openRecentFile();//!< opens a recently used file
   void openSaveHistory();//!< sows the save history dialog
   void outputIsVisible(bool);//!< is Output really visble
-
+  void insertDFIX(double value, double esd, QList<MyAtom> selected, QString resiSpec=""); //!< Insert DFIX restraint into ins file
+  void insertDANG(double value, double esd, QList<MyAtom> selected, QString resiSpec=""); //!< Insert DANG restraint into ins file
+  void insertFLAT(double esd, QList<MyAtom> selected, QString resiSpec=""); //!< Insert FLAT restraint into ins file
+  void insertEXYZ(QList<MyAtom> selected, QString resiSpec=""); //!< Insert EXYZ restraint into ins file
+  void insertEADP(QList<MyAtom> selected, QString resiSpec=""); //!< Insert EADP restraint into ins file
+  void insertDELU(double esd1, double esd2, QList<MyAtom> selected, QString resiSpec=""); //!< Insert DELU restraint into ins file
+  void insertSIMU(double esd1, double esd2, double dmax, QList<MyAtom> selected, QString resiSpec=""); //!< Insert SIMU restraint into ins file
+  void insertISOR(double esd1, double esd2, QList<MyAtom> selected, QString resiSpec=""); //!< Insert ISOR restraint into ins file
+  void insertRIGU(double esd1, double esd2, QList<MyAtom> selected, QString resiSpec=""); //!< Insert RIGU restraint into ins file
+  void insertCHIV(double vol, double esd1, QList<MyAtom> selected, QString resiSpec=""); //!< Insert CHIV restraint into ins file
+  void insertANIS(QList<MyAtom> selected); //!< Insert ANIS for selected atoms
 //  bool peakcomp(MyAtom &a1,MyAtom &a2);
   void redoRename();//!<if redo is clicked and it was a rename a rename is redone.
   void removeExtra(QAbstractButton *button);//!<removes an external program from the menu / tool bar.
@@ -199,6 +213,7 @@ public:
   void runShelXL();//!< copies res to ins file and runs shelxl 
   void runExtra();//!< runs rexternal programs
   void runXLWGHT();//!< runs shelxl for convergeWght. 
+  void resiFinderDestroyed();
   void saveScene();//!< saves a srceen shot of the OpenGL widget
   void schnittart(int trunc);//!< the truncation type of the electron density maps changes to trunc @param trunc new truncation type.
   void sdm();//!< the shortest distance matrix is (re)calculated and the structure is grown
@@ -248,6 +263,7 @@ public:
   void weedEmptySfacs();//!< weeds out unused scattering factors 
   void zoomin(); //!< zoomes in 
   void zoomout();//!< zoomes out 
+  void calculator(); //!< A dialog to work with resolution and 1,3 distances via the angle
 protected:
   void paintEvent(QPaintEvent *event);
   void moveEvent(QMoveEvent *event);
@@ -334,7 +350,7 @@ private:
   QList<Qt::CheckState>  extraArguments,extraExtensions, extraDetach;
   QLineEdit *extraPath,*extraName,*extraAltExtEdit,*extraArgumentsEdit,*shxPath,*shxOptions;
   QDockWidget *helpDock;
-  QWebView *hilfe;
+//  QWebView *hilfe;
   //QTextBrowser *hilfe;
   QWidget *shx_group;
   QVBoxLayout *sss,*amdl;
@@ -345,7 +361,7 @@ private:
   QHBoxLayout *sfacla;
   QScrollArea *qsa,*qsa2;
   QAction *zm_stereo, *pe_stereo, *xe_stereo, *an_stereo, *hw_stereo, *no_stereo; 
-  QAction *fcvsfoAct;
+  QAction *fcvsfoAct, *calcAct;
 
 
 
@@ -436,6 +452,7 @@ private:
   bool maybeSave();  
   bool maybeSave2();
   bool ediVis,oupVis,startFused;
+  Calculator *calcmenu;
 };
 #endif
 
